@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with ciecplib.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Tests for ciecplib
+"""Tests for ciecplib.tool
 """
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
