@@ -100,9 +100,7 @@ EcpIdentityProvider = namedtuple(
 def get_idps(url=DEFAULT_IDPLIST_URL):
     """Download the list of known ECP IdPs from the given URL
 
-    The output is a `dict` where the keys are institution names
-    (e.g. ``'Fermi National Accelerator Laboratory'``), and the values
-    are the URL of their IdP.
+    The output is a `list` of `EcpIdentityProvider` objects.
 
     Some institutions may have two entries if they also support Kerberos.
 
@@ -160,14 +158,16 @@ def _match_institution(value, institutions, kerberos=None):
 
     # try and match the institution name
     matches = _preferred_match(
-        _match(value, institutions, "name", kerberos=kerberos)
+        _match(value, institutions, "name", kerberos=kerberos),
     )
     if len(matches) == 1:
         return matches.pop()
 
     # otherwise match the IdP URL
     if _URL_REGEX.match(value):
-        umatches = _match(value, institutions, "url", kerberos=kerberos)
+        umatches = _preferred_match(
+            _match(value, institutions, "url", kerberos=kerberos),
+        )
         if len(umatches) == 1:
             return umatches.pop()
         matches = matches or umatches or []
